@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2022 Airbyte, Inc., all rights reserved.
+# Copyright (c) 2023 Airbyte, Inc., all rights reserved.
 #
 
 from dataclasses import InitVar, dataclass
@@ -7,11 +7,10 @@ from typing import Any, List, Mapping, Optional
 
 from airbyte_cdk.sources.declarative.interpolation.interpolated_boolean import InterpolatedBoolean
 from airbyte_cdk.sources.declarative.types import Config, Record, StreamSlice, StreamState
-from dataclasses_jsonschema import JsonSchemaMixin
 
 
 @dataclass
-class RecordFilter(JsonSchemaMixin):
+class RecordFilter:
     """
     Filter applied on a list of Records
 
@@ -19,12 +18,12 @@ class RecordFilter(JsonSchemaMixin):
     condition (str): The string representing the predicate to filter a record. Records will be removed if evaluated to False
     """
 
-    options: InitVar[Mapping[str, Any]]
+    parameters: InitVar[Mapping[str, Any]]
     config: Config
     condition: str = ""
 
-    def __post_init__(self, options: Mapping[str, Any]):
-        self._filter_interpolator = InterpolatedBoolean(condition=self.condition, options=options)
+    def __post_init__(self, parameters: Mapping[str, Any]):
+        self._filter_interpolator = InterpolatedBoolean(condition=self.condition, parameters=parameters)
 
     def filter_records(
         self,
