@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2022 Airbyte, Inc., all rights reserved.
+# Copyright (c) 2023 Airbyte, Inc., all rights reserved.
 #
 
 from dataclasses import InitVar, dataclass
@@ -10,11 +10,10 @@ from airbyte_cdk.sources.declarative.extractors.http_selector import HttpSelecto
 from airbyte_cdk.sources.declarative.extractors.record_extractor import RecordExtractor
 from airbyte_cdk.sources.declarative.extractors.record_filter import RecordFilter
 from airbyte_cdk.sources.declarative.types import Record, StreamSlice, StreamState
-from dataclasses_jsonschema import JsonSchemaMixin
 
 
 @dataclass
-class RecordSelector(HttpSelector, JsonSchemaMixin):
+class RecordSelector(HttpSelector):
     """
     Responsible for translating an HTTP response into a list of records by extracting records from the response and optionally filtering
     records based on a heuristic.
@@ -25,11 +24,11 @@ class RecordSelector(HttpSelector, JsonSchemaMixin):
     """
 
     extractor: RecordExtractor
-    options: InitVar[Mapping[str, Any]]
+    parameters: InitVar[Mapping[str, Any]]
     record_filter: RecordFilter = None
 
-    def __post_init__(self, options: Mapping[str, Any]):
-        self._options = options
+    def __post_init__(self, parameters: Mapping[str, Any]):
+        self._parameters = parameters
 
     def select_records(
         self,
