@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2022 Airbyte, Inc., all rights reserved.
+# Copyright (c) 2023 Airbyte, Inc., all rights reserved.
 #
 
 from dataclasses import InitVar, dataclass
@@ -9,11 +9,10 @@ import requests
 from airbyte_cdk.sources.declarative.interpolation.interpolated_string import InterpolatedString
 from airbyte_cdk.sources.declarative.requesters.error_handlers.backoff_strategy import BackoffStrategy
 from airbyte_cdk.sources.declarative.types import Config
-from dataclasses_jsonschema import JsonSchemaMixin
 
 
 @dataclass
-class ExponentialBackoffStrategy(BackoffStrategy, JsonSchemaMixin):
+class ExponentialBackoffStrategy(BackoffStrategy):
     """
     Backoff strategy with an exponential backoff interval
 
@@ -21,14 +20,14 @@ class ExponentialBackoffStrategy(BackoffStrategy, JsonSchemaMixin):
         factor (float): multiplicative factor
     """
 
-    options: InitVar[Mapping[str, Any]]
+    parameters: InitVar[Mapping[str, Any]]
     config: Config
     factor: Union[float, InterpolatedString, str] = 5
 
-    def __post_init__(self, options: Mapping[str, Any]):
+    def __post_init__(self, parameters: Mapping[str, Any]):
         if not isinstance(self.factor, InterpolatedString):
             self.factor = str(self.factor)
-        self.factor = InterpolatedString.create(self.factor, options=options)
+        self.factor = InterpolatedString.create(self.factor, parameters=parameters)
 
     def backoff(self, response: requests.Response, attempt_count: int) -> Optional[float]:
         return self.factor.eval(self.config) * 2**attempt_count
