@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2022 Airbyte, Inc., all rights reserved.
+# Copyright (c) 2023 Airbyte, Inc., all rights reserved.
 #
 
 import logging
@@ -24,7 +24,7 @@ config = {
     "another_field": "exists_in_body",
     "grant_type": "some_grant_type",
 }
-options = {"refresh_token": "some_refresh_token"}
+parameters = {"refresh_token": "some_refresh_token"}
 
 
 class TestOauth2Authenticator:
@@ -41,7 +41,7 @@ class TestOauth2Authenticator:
             token_refresh_endpoint="{{ config['refresh_endpoint'] }}",
             client_id="{{ config['client_id'] }}",
             client_secret="{{ config['client_secret'] }}",
-            refresh_token="{{ options['refresh_token'] }}",
+            refresh_token="{{ parameters['refresh_token'] }}",
             config=config,
             scopes=["scope1", "scope2"],
             token_expiry_date="{{ config['token_expiry_date'] }}",
@@ -50,8 +50,8 @@ class TestOauth2Authenticator:
                 "another_field": "{{ config['another_field'] }}",
                 "scopes": ["no_override"],
             },
-            options=options,
-            grant_type="{{ config['grant_type'] }}"
+            parameters=parameters,
+            grant_type="{{ config['grant_type'] }}",
         )
         body = oauth.build_refresh_request_body()
         expected = {
@@ -79,7 +79,7 @@ class TestOauth2Authenticator:
                 "another_field": "{{ config['another_field'] }}",
                 "scopes": ["no_override"],
             },
-            options={},
+            parameters={},
         )
 
         resp.status_code = 200
@@ -87,9 +87,6 @@ class TestOauth2Authenticator:
         mocker.patch.object(requests, "request", side_effect=mock_request, autospec=True)
         token = oauth.refresh_access_token()
 
-        schem = DeclarativeOauth2Authenticator.json_schema()
-        print(schem)
-
         assert ("access_token", 1000) == token
 
     @pytest.mark.parametrize(
@@ -97,10 +94,10 @@ class TestOauth2Authenticator:
         [
             (86400, None),
             ("2020-01-02T00:00:00Z", "YYYY-MM-DDTHH:mm:ss[Z]"),
-            ('2020-01-02T00:00:00.000000+00:00', "YYYY-MM-DDTHH:mm:ss.SSSSSSZ"),
+            ("2020-01-02T00:00:00.000000+00:00", "YYYY-MM-DDTHH:mm:ss.SSSSSSZ"),
             ("2020-01-02", "YYYY-MM-DD"),
         ],
-        ids=["time_in_seconds", "rfc3339", "iso8601", "simple_date"]
+        ids=["time_in_seconds", "rfc3339", "iso8601", "simple_date"],
     )
     @freezegun.freeze_time("2020-01-01")
     def test_refresh_access_token_expire_format(self, mocker, expires_in_response, token_expiry_date_format):
@@ -120,7 +117,7 @@ class TestOauth2Authenticator:
                 "another_field": "{{ config['another_field'] }}",
                 "scopes": ["no_override"],
             },
-            options={},
+            parameters={},
         )
 
         resp.status_code = 200
