@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2022 Airbyte, Inc., all rights reserved.
+# Copyright (c) 2023 Airbyte, Inc., all rights reserved.
 #
 
 import datetime
@@ -17,6 +17,7 @@ from airbyte_cdk.sources.declarative.interpolation.macros import macros
         ("test_max", "max", True),
         ("test_day_delta", "day_delta", True),
         ("test_format_datetime", "format_datetime", True),
+        ("test_duration", "duration", True),
         ("test_not_a_macro", "thisisnotavalidmacro", False),
     ],
 )
@@ -31,3 +32,8 @@ def test_format_datetime():
     format_datetime = macros["format_datetime"]
     assert format_datetime("2022-01-01T01:01:01Z", "%Y-%m-%d") == "2022-01-01"
     assert format_datetime(datetime.datetime(2022, 1, 1, 1, 1, 1), "%Y-%m-%d") == "2022-01-01"
+
+
+def test_duration():
+    duration = macros["duration"]
+    assert duration("P1D") == datetime.timedelta(days=1)
