@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2022 Airbyte, Inc., all rights reserved.
+# Copyright (c) 2023 Airbyte, Inc., all rights reserved.
 #
 
 from unittest.mock import MagicMock, patch
@@ -9,6 +9,7 @@ import pytest
 import requests
 from airbyte_cdk.models import AirbyteLogMessage, AirbyteMessage, Level, SyncMode, Type
 from airbyte_cdk.sources.declarative.exceptions import ReadException
+from airbyte_cdk.sources.declarative.incremental import DatetimeBasedCursor
 from airbyte_cdk.sources.declarative.requesters.error_handlers.response_action import ResponseAction
 from airbyte_cdk.sources.declarative.requesters.error_handlers.response_status import ResponseStatus
 from airbyte_cdk.sources.declarative.requesters.request_option import RequestOptionType
@@ -19,7 +20,6 @@ from airbyte_cdk.sources.declarative.retrievers.simple_retriever import (
     _prepared_request_to_airbyte_message,
     _response_to_airbyte_message,
 )
-from airbyte_cdk.sources.declarative.stream_slicers import DatetimeStreamSlicer
 from airbyte_cdk.sources.streams.http.auth import NoAuth
 from airbyte_cdk.sources.streams.http.http import HttpStream
 
@@ -46,14 +46,14 @@ def test_simple_retriever_full(mock_http_stream):
     record_selector = MagicMock()
     record_selector.select_records.return_value = records
 
-    iterator = MagicMock()
+    stream_slicer = MagicMock()
     stream_slices = [{"date": "2022-01-01"}, {"date": "2022-01-02"}]
-    iterator.stream_slices.return_value = stream_slices
+    stream_slicer.stream_slices.return_value = stream_slices
 
     response = requests.Response()
 
     underlying_state = {"date": "2021-01-01"}
-    iterator.get_stream_state.return_value = underlying_state
+    stream_slicer.get_stream_state.return_value = underlying_state
 
     requester.get_authenticator.return_value = NoAuth()
     url_base = "https://airbyte.io"
@@ -85,8 +85,8 @@ def test_simple_retriever_full(mock_http_stream):
         requester=requester,
         paginator=paginator,
         record_selector=record_selector,
-        stream_slicer=iterator,
-        options={},
+        stream_slicer=stream_slicer,
+        parameters={},
         config={},
     )
 
@@ -122,8 +122,15 @@ def test_simple_retriever_with_request_response_logs(mock_http_stream):
     requester = MagicMock()
     paginator = MagicMock()
     record_selector = MagicMock()
-    iterator = DatetimeStreamSlicer(
-        start_datetime="", end_datetime="", step="P1D", cursor_field="id", datetime_format="", cursor_granularity="P1D", config={}, options={}
+    stream_slicer = DatetimeBasedCursor(
+        start_datetime="",
+        end_datetime="",
+        step="P1D",
+        cursor_field="id",
+        datetime_format="",
+        cursor_granularity="P1D",
+        config={},
+        parameters={},
     )
 
     retriever = SimpleRetriever(
@@ -132,8 +139,8 @@ def test_simple_retriever_with_request_response_logs(mock_http_stream):
         requester=requester,
         paginator=paginator,
         record_selector=record_selector,
-        stream_slicer=iterator,
-        options={},
+        stream_slicer=stream_slicer,
+        parameters={},
         config={},
     )
 
@@ -153,8 +160,15 @@ def test_simple_retriever_with_request_response_log_last_records(mock_http_strea
     record_selector = MagicMock()
     record_selector.select_records.return_value = request_response_logs
     response = requests.Response()
-    iterator = DatetimeStreamSlicer(
-        start_datetime="", end_datetime="", step="P1D", cursor_field="id", datetime_format="", cursor_granularity="P1D", config={}, options={}
+    stream_slicer = DatetimeBasedCursor(
+        start_datetime="",
+        end_datetime="",
+        step="P1D",
+        cursor_field="id",
+        datetime_format="",
+        cursor_granularity="P1D",
+        config={},
+        parameters={},
     )
 
     retriever = SimpleRetriever(
@@ -163,8 +177,8 @@ def test_simple_retriever_with_request_response_log_last_records(mock_http_strea
         requester=requester,
         paginator=paginator,
         record_selector=record_selector,
-        stream_slicer=iterator,
-        options={},
+        stream_slicer=stream_slicer,
+        parameters={},
         config={},
     )
 
@@ -189,7 +203,7 @@ def test_simple_retriever_with_request_response_log_last_records(mock_http_strea
 def test_should_retry(test_name, requester_response, expected_should_retry, expected_backoff_time):
     requester = MagicMock(use_cache=False)
     retriever = SimpleRetriever(
-        name="stream_name", primary_key=primary_key, requester=requester, record_selector=MagicMock(), options={}, config={}
+        name="stream_name", primary_key=primary_key, requester=requester, record_selector=MagicMock(), parameters={}, config={}
     )
     requester.interpret_response_status.return_value = requester_response
     assert retriever.should_retry(requests.Response()) == expected_should_retry
@@ -223,7 +237,7 @@ def test_parse_response(test_name, status_code, response_status, len_expected_re
     record_selector = MagicMock()
     record_selector.select_records.return_value = [{"id": 100}]
     retriever = SimpleRetriever(
-        name="stream_name", primary_key=primary_key, requester=requester, record_selector=record_selector, options={}, config={}
+        name="stream_name", primary_key=primary_key, requester=requester, record_selector=record_selector, parameters={}, config={}
     )
     response = requests.Response()
     response.request = requests.Request()
@@ -255,7 +269,7 @@ def test_backoff_time(test_name, response_action, retry_in, expected_backoff_tim
     record_selector.select_records.return_value = [{"id": 100}]
     response = requests.Response()
     retriever = SimpleRetriever(
-        name="stream_name", primary_key=primary_key, requester=requester, record_selector=record_selector, options={}, config={}
+        name="stream_name", primary_key=primary_key, requester=requester, record_selector=record_selector, parameters={}, config={}
     )
     if expected_backoff_time:
         requester.interpret_response_status.return_value = ResponseStatus(response_action, retry_in)
@@ -306,7 +320,7 @@ def test_get_request_options_from_pagination(test_name, paginator_mapping, strea
         record_selector=record_selector,
         paginator=paginator,
         stream_slicer=stream_slicer,
-        options={},
+        parameters={},
         config={},
     )
 
@@ -352,7 +366,7 @@ def test_get_request_headers(test_name, paginator_mapping, expected_mapping):
         requester=requester,
         record_selector=record_selector,
         paginator=paginator,
-        options={},
+        parameters={},
         config={},
     )
 
@@ -396,7 +410,7 @@ def test_request_body_data(test_name, requester_body_data, paginator_body_data,
         requester=requester,
         record_selector=record_selector,
         paginator=paginator,
-        options={},
+        parameters={},
         config={},
     )
 
@@ -432,7 +446,7 @@ def test_path(test_name, requester_path, paginator_path, expected_path):
         requester=requester,
         record_selector=record_selector,
         paginator=paginator,
-        options={},
+        parameters={},
         config={},
     )
 
@@ -644,7 +658,7 @@ def test_limit_stream_slices():
         record_selector=MagicMock(),
         stream_slicer=stream_slicer,
         maximum_number_of_slices=maximum_number_of_slices,
-        options={},
+        parameters={},
         config={},
     )
 
